"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const fs = require("fs");
const base_1 = require("../base");
const conf_1 = require("../services/conf");
const logger_1 = require("../services/logger");
const message_1 = require("../services/message");
class RunBase extends base_1.default {
    constructor() {
        super(...arguments);
        this.cmd = '';
        this.watch = false;
    }
    async preInit() {
        // @ts-ignore
        const { flags, args } = this.parse(this.constructor);
        this.cmd = args.cmd;
        this.watch = flags.watch;
        this.extras = flags.extras;
        return flags;
    }
    async initialize() {
        const { appConfPath, rdcConfPath, RdTypes, dockerRdcDir, } = conf_1.default;
        const isDockerEnv = process.env.DOCKER_ENV;
        if (fs.existsSync(appConfPath)) {
            conf_1.default.rdType = RdTypes.Application;
        }
        else if (isDockerEnv && fs.existsSync(dockerRdcDir) ||
            !isDockerEnv && fs.existsSync(rdcConfPath)) {
            // runbase is used by both local env & docker env
            conf_1.default.rdType = RdTypes.Container;
        }
        logger_1.debug(`rd type recognized as ${conf_1.default.rdType}`);
        if (!conf_1.default.rdType) {
            throw Error(message_1.MCOMMON.UNRECOGNIZED);
        }
    }
    async run() { }
}
RunBase.args = [{
        name: 'cmd',
        required: false,
        description: 'scripts provided by container',
    }];
RunBase.flags = Object.assign({}, base_1.default.flags, { watch: command_1.flags.boolean({ char: 'w' }), extras: command_1.flags.string({
        char: 'e',
        description: 'arguments need to pass to npm run cmd',
    }) });
exports.default = RunBase;
