"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const cache_1 = require("../../services/cache");
const conf_1 = require("../../services/conf");
const docker_1 = require("../../services/docker");
const render_1 = require("../../services/render");
const sync_1 = require("../../services/sync");
const util_1 = require("../../util");
const index_1 = require("./index");
const { join, resolve } = path;
class ApplicationCreate extends index_1.default {
    constructor() {
        super(...arguments);
        this.rdcConf = null;
    }
    async prepare() {
        await docker_1.default.pull(this.rdc);
        await util_1.default.asyncExec(`mkdir ${conf_1.default.localCacheDir}`);
        cache_1.default.set('container', this.rdc);
        const { cwd, rdcConfName, dockerRdcDir, } = conf_1.default;
        const rdcConfPath = resolve(conf_1.default.localCacheDir, rdcConfName);
        await sync_1.default.genAppStagedFiles(this.rdc);
        this.rdcConf = require(rdcConfPath);
        const { exportFiles = [] } = this.rdcConf;
        if (exportFiles.length) {
            await docker_1.default.copy(this.rdc, exportFiles.map(filePath => ({
                from: resolve(dockerRdcDir, filePath),
                to: resolve(cwd, filePath, '../'),
            })));
        }
    }
    async genConfFile() {
        const { appConfName } = conf_1.default;
        const { docs, docker = { ports: [] } } = this.rdcConf;
        await render_1.default.renderTo(join('rda', appConfName.slice(0, -3)), {
            container: this.rdc,
            docs: docs ? docs.url : '',
            ports: docker.ports,
        }, appConfName);
    }
    async genExtraFiles() {
        const { exportFiles = [] } = this.rdcConf;
        await render_1.default.renderTo(join('rda', 'README'), {
            name: this.name,
            homepage: conf_1.default.homepage,
        }, 'README.md');
        await render_1.default.renderTo('app.gitignore', {
            exportFiles,
            appBasicFiles: conf_1.default.appBasicFiles,
        }, '.gitignore', {
            overwrite: true,
        });
    }
}
exports.default = ApplicationCreate;
