"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const conf_1 = require("../services/conf");
const ide_1 = require("../services/ide");
const logger_1 = require("../services/logger");
const render_1 = require("../services/render");
const sync_1 = require("../services/sync");
const watcher_1 = require("../services/watcher");
const util_1 = require("../util");
const { resolve } = path;
const { RdTypes, dockerRdcDir, dockerRdaDir, dockerWorkDirRoot, appConfName, rdcConfName, } = conf_1.default;
class DockerRun {
    get dataView() {
        if (conf_1.default.rdType === RdTypes.Application) {
            const appConf = require(resolve(dockerWorkDirRoot, appConfName));
            const { container = {}, suites = {} } = appConf;
            if (suites && suites.length) {
                container.render = container.render || {};
                container.render.suites = suites;
            }
            logger_1.debug('docker:run dataView: ', container.render);
            return container.render || {};
        }
        if (conf_1.default.rdType === RdTypes.Container) {
            const rdcConf = require(resolve(dockerRdcDir, rdcConfName));
            rdcConf.render = rdcConf.render || {};
            logger_1.debug('docker:run dataView: ', rdcConf.render.mock);
            return rdcConf.render.mock || {};
        }
    }
    get includes() {
        const rdcConf = require(resolve(dockerRdcDir, rdcConfName));
        rdcConf.render = rdcConf.render || {};
        logger_1.debug('docker:run includes: ', rdcConf.render.includes);
        return rdcConf.render.includes || [];
    }
    get exportFiles() {
        const rdcConf = require(resolve(dockerRdcDir, rdcConfName));
        rdcConf.exportFiles = rdcConf.exportFiles || [];
        logger_1.debug('docker:run export Files: ', rdcConf.exportFiles);
        return rdcConf.exportFiles;
    }
    get ignoredFiles() {
        if (conf_1.default.isApp) {
            return [
                ...this.exportFiles,
                ...conf_1.default.appBasicFiles,
                'node_modules',
            ];
        }
        return [];
    }
    constructor({ watch }) {
        this.watch = watch;
    }
    async start() {
        // render /rdc dir to /rde
        await this.renderDir();
        if (conf_1.default.isApp) {
            // add vscode settings to local .vscode/settings.json
            // filter everything except exportFiles and appBasicFiles
            await util_1.default.asyncExec('mkdir -p .vscode');
            const ignore = this.ignoredFiles.concat(['rdc', 'rda']);
            await ide_1.default.initAppExcludeSettings(ignore);
            // merge appPkgJson & rdcPkgJson to /rde
            await sync_1.default.mergePkgJson(resolve(dockerRdaDir, 'package.json'), resolve(dockerRdcDir, 'package.json'), resolve(dockerWorkDirRoot));
        }
    }
    async renderDir() {
        let ignore = this.ignoredFiles;
        if (conf_1.default.isApp) {
            ignore = ignore.concat(['package.json']);
        }
        await render_1.default.renderDir(dockerRdcDir, Object.assign({}, this.dataView), this.includes, dockerWorkDirRoot, {
            overwrite: true,
            dot: true,
            filter(src) {
                return !ignore.some(item => {
                    const escaped = item.replace(/[-\/\\^$*+?.()|[\]{}]/g, '\\$&');
                    const regexp = new RegExp(`^${escaped}`);
                    return regexp.test(src);
                });
            },
        });
        if (this.watch &&
            conf_1.default.rdType === RdTypes.Container) {
            new watcher_1.default([{
                    from: dockerRdcDir,
                    to: dockerWorkDirRoot,
                }]).start();
        }
    }
}
exports.default = DockerRun;
