"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const globby = require("globby");
const path = require("path");
const conf_1 = require("./conf");
const logger_1 = require("./logger");
const render_1 = require("./render");
const { resolve } = path;
class IDE {
    get rdcConfPath() {
        return resolve(conf_1.default.localCacheDir, conf_1.default.rdcConfName);
    }
    get eslintPkgPath() {
        return resolve(conf_1.default.cwd, 'node_modules', 'eslint');
    }
    get eslintrcPath() {
        return resolve(conf_1.default.cwd, '.eslintrc.js');
    }
    async initSettings(isApp) {
        logger_1.debug(`eslint pkg path: ${this.eslintPkgPath}`);
        logger_1.debug(`eslintrc path: ${this.eslintrcPath}`);
        await render_1.default.renderDir(resolve(__dirname, '..', 'mustaches', 'ide'), {
            eslintPkgPath: this.eslintPkgPath,
            eslintrcPath: this.eslintrcPath,
            isApp,
        }, ['.xml', '.json', '.iml'], conf_1.default.cwd, {
            overwrite: true,
        });
    }
    async initAppExcludeSettings(ignore) {
        let excludePaths = await globby(['**/*'], {
            onlyFiles: false,
            ignore,
            dot: true,
        });
        excludePaths = excludePaths.filter(item => {
            const escaped = item.replace(/[-\/\\^$*+?.()|[\]{}]/g, '\\$&');
            const regexp = new RegExp(`^${escaped}`);
            return !ignore.some(file => regexp.test(file));
        });
        let excludes = {};
        excludePaths.forEach(item => {
            excludes[item] = true;
        });
        fs.writeFileSync('.vscode/settings.json', JSON.stringify({
            'files.exclude': Object.assign({ rdc: true }, excludes)
        }), { encoding: 'UTF-8' });
    }
}
exports.default = new IDE();
