"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const conf_1 = require("./conf");
const message_1 = require("./message");
exports.validateRda = (useStrict = false) => {
    return useStrict;
};
exports.validateRdc = (useStrict = false) => {
    const { rdcConfPath, frameworks, } = conf_1.default;
    if (!fs.existsSync(rdcConfPath)) {
        throw Error(message_1.MRDC.UNRECOGNIZED);
    }
    const rdcConf = require(rdcConfPath);
    if (!rdcConf.framework ||
        !Object.keys(frameworks).includes(rdcConf.framework)) {
        throw Error(message_1.MCOMMON.WRONG_FRAMEWORK_CONFIG);
    }
    const { docker, exportFiles, docs } = rdcConf;
    if (!docker || !docker.ports || !docker.ports.length) {
        throw Error(message_1.MCOMMON.WRONG_DOCKER_CONFIG_PORTS);
    }
    if (useStrict && !docker.tag) {
        throw Error(message_1.MCOMMON.WRONG_DOCKER_CONFIG_TAG);
    }
    if (!exportFiles || !exportFiles.length) {
        throw Error(message_1.MCOMMON.WRONG_MAPPING_CONFIG_MAPPING);
    }
    if (useStrict && (!docs || !docs.url)) {
        throw Error(message_1.MCOMMON.WRONG_DOCS_CONFIG);
    }
    return rdcConf;
};
